# Electron Microscopy Machine Learning (EMicroML)

[![Test library](https://github.com/mrfitzpa/emicroml/actions/workflows/test_library.yml/badge.svg)](https://github.com/mrfitzpa/emicroml/actions/workflows/test_library.yml)
[![Code Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/mrfitzpa/14251fa16826487aa533af3cfe6887d4/raw/emicroml_coverage_badge.json)](https://github.com/mrfitzpa/emicroml/actions/workflows/measure_code_coverage.yml)
[![Documentation](https://img.shields.io/badge/docs-read-brightgreen)](https://mrfitzpa.github.io/emicroml)
[![PyPi Version](https://img.shields.io/pypi/v/emicroml.svg)](https://pypi.org/project/emicroml)
[![Conda-Forge Version](https://img.shields.io/conda/vn/conda-forge/emicroml.svg)](https://anaconda.org/conda-forge/emicroml)
[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

`emicroml` is a Python library for training machine learning models for
applications in electron microscopy.

Visit the `emicroml` [website](https://mrfitzpa.github.io/emicroml) for a web
version of the installation instructions, the reference guide, and the examples
archive.

<!--
For those reading raw .rst files, see file `docs/INSTALL.rst` for instructions
on installing the `emicroml` library.
-->